@@ -2,12 +2,14 @@ from .core import (
     gerar_df_phoenix,
     abrir_planilha,
     tratar_colunas_df,
-    gsheet_to_df
+    gsheet_to_df,
+    plotar_tabela_aggrid_colher_selecao
 )
 
 __all__ = [
     "gerar_df_phoenix",
     "abrir_planilha",
     "tratar_colunas_df",
-    "gsheet_to_df"
+    "gsheet_to_df",
+    "plotar_tabela_aggrid_colher_selecao"
 ]
