@@ -4,6 +4,7 @@ import decimal
 import gspread
 from google.oauth2 import service_account
 from typing import Optional
+from st_aggrid import AgGrid, GridOptionsBuilder
 
 # Função para gerar DataFrame a partir de uma view do Phoenix
 
@@ -197,3 +198,43 @@ def gsheet_to_df(
     )
 
     return df
+
+# Função para plotar tabela interativa e colher a seleção do usuário
+
+def plotar_tabela_aggrid_colher_selecao(
+        df: pd.DataFrame,
+        config_selection: str,
+        use_checkbox: bool,
+        header_checkbox: bool,
+        autoHeight: bool,
+        autoWidth: bool
+    ) -> list:
+
+    gb = GridOptionsBuilder.from_dataframe(df)
+
+    gb.configure_selection(
+        config_selection, 
+        use_checkbox=use_checkbox, 
+        header_checkbox=header_checkbox
+    )
+
+    if autoHeight:
+
+        gb.configure_grid_options(domLayout='autoHeight')
+
+    if autoWidth:
+
+        gb.configure_grid_options(domLayout='autoWidth')
+
+    gridOptions = gb.build()
+
+    grid_response = AgGrid(
+        df, 
+        gridOptions=gridOptions, 
+        enable_enterprise_modules=False, 
+        fit_columns_on_grid_load=True
+    )
+
+    selected_rows = grid_response['selected_rows']
+
+    return selected_rows
